%define dotpl .3
%define dashpl -3

Summary: PDE solving tool
Name: freefem++
Version: 3.31
Release: 1%{?dotpl}%{?dist}
URL: http://www.freefem.org/ff++/index.htm
Source0: http://www.freefem.org/ff++/ftp/%{name}-%{version}%{?dashpl}.tar.gz
Source1: FreeFem++.1
Patch0: %{name}-rpm.patch
Patch5: %{name}-compile.patch
License: LGPLv2+
BuildRequires:	arpack-devel
BuildRequires:	atlas-devel
BuildRequires:	bison
BuildRequires:	environment-modules
BuildRequires:	fftw-devel
BuildRequires:	flex
BuildRequires:	fltk-devel
BuildRequires:	gcc-gfortran
BuildRequires:	glut-devel
BuildRequires:	gmm-devel
BuildRequires:	gsl-devel
BuildRequires:	ImageMagick
BuildRequires:	lapack-devel
BuildRequires:	libGLU-devel
BuildRequires:	libtool
BuildRequires:	libXpm-devel
BuildRequires:	libXt-devel
BuildRequires:	libXxf86vm-devel
#BuildRequires:	metis-devel
# mumps code requires metis and scotch
#BuildRequires:	MUMPS-devel
#scotch package is broken
#BuildRequires:	scotch-devel
BuildRequires:	suitesparse-devel
BuildRequires:	SuperLU-devel
BuildRequires:	tetgen-devel
BuildRequires:	texlive-multirow
BuildRequires:	texlive-was
BuildRequires:	%{_bindir}/dvips
BuildRequires:	%{_bindir}/epstopdf
BuildRequires:	%{_bindir}/pdflatex
Obsoletes: %{name}-glx < 3.23-1
Obsoletes: %{name}-devel < 3.26-1
Provides: %{name}-glx = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description
A PDE oriented language using Finite Element Method FreeFem++ is an
implementation of a language dedicated to the finite element method. It
provides you a way to solve Partial Differential Equations (PDE) simply.

Problems involving partial differential equations (pde) of  several
branches of physics such as fluid-structure interactions require
interpolations of data on several meshes and their manipulation within
one program.

FreeFem++ is an extension of freefem, freefem+ written in C++.

Homepage: http://www.freefem.org/

%package openmpi
Summary: PDE solving tool - OpenMPI version
BuildRequires: openmpi-devel >= 1.3.3-2
BuildRequires: blacs-openmpi-devel
BuildRequires: scalapack-openmpi-devel
#BuildRequires: MUMPS-openmpi-devel
Obsoletes: %{name}-mpi < 3.19-5
Provides: %{name}-mpi = %{name}-%{version}
Requires: %{name} = %{version}-%{release}
# For dir ownership
Requires: openmpi
Requires: blacs-openmpi
Requires: scalapack-openmpi

%description openmpi
This package contains the OpenMPI version of FreeFem++.

%package mpich
Summary: PDE solving tool - MPICH version
BuildRequires: mpich-devel
BuildRequires: blacs-mpich-devel
BuildRequires: scalapack-mpich2-devel
#BuildRequires: MUMPS-mpich-devel
Obsoletes: %{name}-mpi < 3.19-5
Provides: %{name}-mpi = %{name}-%{version}
Requires: %{name} = %{version}-%{release}
# For dir ownership
Requires: mpich
Requires: blacs-mpich
Requires: scalapack-mpich

%description mpich
This package contains the MPICH version of FreeFem++.

%prep
%setup -q -c -T -a 0
mv %{name}-%{version}%{dashpl} serial
pushd serial
%patch0 -p1 -b .r
%patch5 -p1 -b .compile
%if 0%{?fedora} >= 21
sed -i 's|-lmpiblacsCinit -lmpiblacsF77init||g' configure
%endif

find . -type f -perm 755 \( -name "*.c*" -o -name "*.h*" -o -name "*.edp" -o -name "*.idp" \) | xargs chmod 644
for file in AUTHORS ChangeLog COPYRIGHT COPYING HISTORY ; do
	iconv -f iso8859-1 -t utf8 -o $file.utf8 $file && \
	touch -r $file $file.utf8 && \
	mv $file.utf8 $file
done
autoreconf -vif
popd

# MPI flavors
cp -r serial openmpi
cp -r serial mpich

%build
export CFLAGS+=" %{optflags}"

pushd serial
%configure \
	INSTALL="%{__install} -p" \
	--disable-download \
	--disable-optim \
	--disable-hips \
	--disable-ipopt \
	--disable-metis \
	--disable-mmg3d \
	--disable-mshmet \
	--disable-mumps \
	--disable-mumps_seq \
	--disable-nlopt \
	--disable-parmetis \
	--disable-pastix \
	--disable-scotch \
	--disable-yams \
	--enable-opengl \
	--with-blas="-L%{_libdir}/atlas -lsatlas" \
	--with-mpi=no \

make
popd

for mpi in mpich openmpi ; do
pushd ${mpi}
. /etc/profile.d/modules.sh
module load mpi/${mpi}-%{_arch}
export CFLAGS="$CFLAGS %{optflags}"
%configure \
	INSTALL="%{__install} -p" \
	--disable-download \
	--disable-optim \
	--disable-hips \
	--disable-ipopt \
	--disable-metis \
	--disable-mmg3d \
	--disable-mshmet \
	--disable-mumps \
	--disable-mumps_seq \
	--disable-nlopt \
	--disable-parmetis \
	--disable-pastix \
	--disable-scotch \
	--disable-tetgen \
	--disable-yams \
	--enable-opengl \
	--with-blas="-L%{_libdir}/atlas -lsatlas" \
	--with-mpi=yes \

make
# %{?_smp_mflags}
module unload mpi/${mpi}-%{_arch}
popd
done

%install
pushd serial
make DESTDIR=%{buildroot} install
chmod 744 %{buildroot}%{_libdir}/ff++/lib/*.so
chmod 644 %{buildroot}%{_libdir}/ff++/lib/WHERE*
install -d %{buildroot}%{_mandir}/man1/
install -pm644 %{SOURCE1} %{buildroot}%{_mandir}/man1/
pushd %{buildroot}%{_datadir}/freefem++
rm -r download
rm BUGS COPYRIGHT HISTORY* INNOVATION INSTALL{,-MacOSX} README{,_MAC,_WINDOWS} TODO freefem++doc.pdf mode-mi-edp.zip
popd
rm %{buildroot}{%{_bindir},%{_libdir}/ff++/bin}/ff-pkg-download
# the binary with no suffix should be the generic X11 one according to README
# the build system makes it identical to -nw version, so overwrite it
ln -sf FreeFem++-nw %{buildroot}%{_bindir}/FreeFem++
popd

for mpi in openmpi mpich ; do
  pushd $mpi
  make DESTDIR=`pwd`/buildtree install
  for bin in FreeFem++-mpi ff-mpirun ; do
    install -D -m 755 -p buildtree/%{_bindir}/$bin %{buildroot}%{_libdir}/${mpi}/bin/${bin}_${mpi}
  done
  for lib in MPICG.so mpi-cmaes.so ; do
    install -D -m 744 -p buildtree/%{_libdir}/ff++/lib/$lib %{buildroot}%{_libdir}/${mpi}/lib/ff++/lib/$lib
  done
  popd
done

%if 0
%check
pushd serial
export CFLAGS+=" %{optflags}"
make check
popd
%endif

%files
%doc serial/AUTHORS serial/BUGS serial/COPYING serial/COPYRIGHT serial/HISTORY serial/INNOVATION serial/README serial/TODO
%doc serial/DOC/freefem++doc.pdf
%{_mandir}/man1/*
%{_bindir}/FreeFem++
%{_bindir}/FreeFem++-nw
%{_bindir}/bamg
%{_bindir}/cvmsh2
%{_bindir}/ffglut
%{_bindir}/ffmedit
%{_libdir}/ff++
%{_bindir}/ff-c++
%{_bindir}/ff-get-dep
%{_datadir}/freefem++

%files openmpi
%{_libdir}/openmpi/bin/FreeFem++-mpi_openmpi
%{_libdir}/openmpi/bin/ff-mpirun_openmpi
%{_libdir}/openmpi/lib/ff++

%files mpich
%{_libdir}/mpich/bin/FreeFem++-mpi_mpich
%{_libdir}/mpich/bin/ff-mpirun_mpich
%{_libdir}/mpich/lib/ff++

%changelog
* Fri Sep 19 2014 Dominik Mierzejewski <rpm@greysector.net> 3.31-1.3
- update to 3.31-3 (rhbz#1116574)
- disable blas download attempts during build

* Sat Sep 06 2014 Rex Dieter <rdieter@fedoraproject.org> 3.30-5
- rebuild (gmm), use %{?..} macro variants (for those possibly not defined or set to %%nil))

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.30-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 29 2014 Dominik Mierzejewski <rpm@greysector.net> 3.30-3
- build against tetgen

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.30-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 25 2014 Dominik Mierzejewski <rpm@greysector.net> 3.30-1
- update to 3.30

* Mon May 12 2014 Tom Callaway <spot@fedoraproject.org> 3.29-2
- compile against new blacs

* Mon Mar 10 2014 Dominik Mierzejewski <rpm@greysector.net> 3.29-1
- update to 3.29
- reduce redundant spec code

* Tue Feb 25 2014 Dominik Mierzejewski <rpm@greysector.net> 3.27-3
- fix compilation and build against SuperLU

* Sun Feb 23 2014 Dominik Mierzejewski <rpm@greysector.net> 3.27-2
- rebuild for mpich-3.1

* Sun Feb 16 2014 Dominik Mierzejewski <rpm@greysector.net> 3.27-1
- update to 3.27

* Fri Dec 06 2013 Nils Philippsen <nils@redhat.com> - 3.26-2.2
- rebuild (suitesparse)

* Thu Nov 28 2013 Dominik Mierzejewski <rpm@greysector.net> 3.26-1.2
- update to 3.26-2
- build with proper multi-MPI support
- build with gmm support
- WIP mumps/metis/scotch support (disabled for now)
- add missing tex dependencies
- drop obsolete patches
- explicitly disable all unavailable dependencies
- drop devel subpackage
- drop obsolete specfile constructs
- fix build with new atlas

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.19-5.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.19-4.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.19-3.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jul 14 2012 Dominik Mierzejewski <rpm@greysector.net> 3.19-2.1
- move MPI plugins to mpi subpackage

* Fri Jul 13 2012 Dominik Mierzejewski <rpm@greysector.net> 3.19-1.1
- update to 3.19-1
- rebased patches
- dropped upstreamed patch
- enable gsl interface
- added missing include which breaks compilation with gcc-4.7

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12-3
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Feb 27 2011 Dominik Mierzejewski <rpm@greysector.net> 3.12-1
- update to 3.12
- rebased patches

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 14 2010 Dominik Mierzejewski <rpm@greysector.net> 3.11-1
- update to 3.11
- fix build
- fix duplicate binaries in the main package

* Mon Nov 15 2010 Dominik Mierzejewski <rpm@greysector.net> 3.10-1
- update to 3.10-1
- drop no longer necessary gcc-4.5 patch

* Sat Sep 04 2010 Dominik Mierzejewski <rpm@greysector.net> 3.9-3.2
- update to 3.9-2

* Sun Aug 29 2010 Dominik Mierzejewski <rpm@greysector.net> 3.9-2.1
- update to 3.9-1

* Wed Aug 04 2010 Dominik Mierzejewski <rpm@greysector.net> 3.9-1
- update to 3.9
- fix compilation with gcc-4.5.1

* Thu Feb 25 2010 Dominik Mierzejewski <rpm@greysector.net> 3.8-1
- update to 3.8
- fix FTBFS (rhbz #564731)

* Fri Jan 15 2010 Dominik Mierzejewski <rpm@greysector.net> 3.7-1.1
- update to 3.7-1
- disable testsuite again (rhbz #524511)

* Sat Dec  5 2009 Dominik Mierzejewski <rpm@greysector.net> 3.6-1.1
- update to 3.6-1
- drop upstream'd/obsolete patches
- move scripts to %%{_datadir}
- reenable testsuite

* Mon Sep 21 2009 Dominik Mierzejewski <rpm@greysector.net> 3.5-2
- disable testsuite

* Sun Sep 20 2009 Dominik Mierzejewski <rpm@greysector.net> 3.5-1
- update to 3.5
- adjust environment modules setup for current version
- use openmpi instead of lam (regression tests pass locally)
- remove irrelevant READMEs and old changelogs from docs
- add examples to -devel subpackage
- fix some minor build problems

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0-6.5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Dominik Mierzejewski <rpm@greysector.net> 3.0-5.5
- update to 3.0-5
- fix build with gcc-4.4
- fix build with Fedora-mandated CFLAGS
- sort BRs alphabetically

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0-3.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 15 2008 Deji Akingunola <dakingun@gmail.com> - 3.0-2.3
- Rebuild for atlas-3.8.2

* Wed Dec 10 2008 Dominik Mierzejewski <rpm@greysector.net> 3.0-2.2
- update to 3.0-2
- fix compilation
- fix installation paths and path substitution in ff-c++
- preserve timestamps in make install
- add missing BR
- disable regression tests for now

* Fri Dec 05 2008 Dominik Mierzejewski <rpm@greysector.net> 3.0-1.1
- update to 3.0
- fixed build of pdf doc
- dropped obsolete patch

* Wed Oct 01 2008 Dominik Mierzejewski <rpm@greysector.net> 2.24-5.2
- fix encoding of some doc files
- fix author's name in COPYRIGHT

* Sun Sep 28 2008 Dominik Mierzejewski <rpm@greysector.net> 2.24-4.2
- disabled testsuite on ppc64
- kill lamd processes upon completing make check

* Wed Sep 24 2008 Dominik Mierzejewski <rpm@greysector.net> 2.24-3.2
- updated to 2.24-2
- fixed build in rawhide
- re-enable testsuite

* Fri Feb 22 2008 Dominik Mierzejewski <rpm@greysector.net> 2.24-2
- fix build on ppc64

* Fri Feb 22 2008 Dominik Mierzejewski <rpm@greysector.net> 2.24-1
- updated to 2.24

* Wed Feb 20 2008 Dominik Mierzejewski <rpm@greysector.net> 2.23-1
- updated to 2.23
- fixed build with gcc-4.3 (with help from Denis Leroy)
- use file deps for latex tools
- MPI part doesn't build on ppc64 (bug #433870)

* Sun Apr 29 2007 Dominik Mierzejewski <rpm@greysector.net> 2.16-2
- enable testsuite
- remove load tests from testsuite, the rest completes fine

* Sat Apr 28 2007 Dominik Mierzejewski <rpm@greysector.net> 2.16-1
- updated to 2.16-2
- simplified defattr
- work around X11 "detection"
- work around lam's mpicxx.h misdetection in configure

* Tue Mar 27 2007 Dominik Mierzejewski <rpm@greysector.net> 2.14-2
- updated to 2.14-2

* Mon Mar 19 2007 Dominik Mierzejewski <rpm@greysector.net> 2.14-1
- updated to 2.14-1
- removed redundant builddeps

* Thu Nov 23 2006 Dominik Mierzejewski <rpm@greysector.net> 2.11-2
- specfile cleanups
- added manpage from CVS

* Fri Nov 17 2006 Dominik Mierzejewski <rpm@greysector.net> 2.11-1
- updated to 2.11
- specfile cleanups

* Tue Jun 27 2006 Dominik Mierzejewski <rpm@greysector.net>
- updated to latest CVS

* Mon May 15 2006 Dominik Mierzejewski <rpm@greysector.net>
- split into subpackages

* Wed Apr 26 2006 Dominik Mierzejewski <rpm@greysector.net>
- initial build
